@@ -437,11 +437,19 @@ class NaPoleonXConnector(object):
 #    url_product = 'https://api.napoleonx.ai/product-service/v1/product/'
 
 #    url_auth = 'http://15.237.36.185:9000/auth-service/oauth/token'
+
     url_auth = 'http://15.237.36.185:9000/oauth/token'
     url = 'http://15.237.36.185:9000/v1/quote-service/filter'
     signal_url = 'http://15.237.36.185:9000/v1/position-service/filter'
     url_product = 'http://15.237.36.185:9000/v1/product-service/'
 
+    # url_auth = 'https://api.napoleonx.ai/oauth/token'
+    # url = 'https://api.napoleonx.ai/v1/quote-service/filter'
+    # signal_url = 'https://api.napoleonx.ai/v1/position-service/filter'
+    # url_product = 'https://api.napoleonx.ai/v1/product-service/'
+
+    #    url_auth = 'http://15.237.36.185:9000/auth-service/oauth/token'
+
     data = {
         'grant_type': 'password',
 #        'scope': 'read write',
@@ -460,12 +468,13 @@ class NaPoleonXConnector(object):
 
         self.data.update({'username': username, 'password': password})
 
-        response = requests.post(
+        response_w = requests.post(
             self.url_auth,
             data=self.data,
             headers=self.headers,
             auth=auth
-        ).json()
+        )
+        response=response_w.json()
 
         # Set token
         self.token = response['access_token']
@@ -610,7 +619,7 @@ class NaPoleonXConnector(object):
 
         """
         json_data = self.get_data(productCodes, minDate, maxDate)
-        data = pd.DataFrame(json_data)
+        data = pd.DataFrame(json_data['data'])
         df = self._set_dataframe(data, assets=productCodes, keep=keep)
         df.index = pd.to_datetime(df.index, format='%Y-%m-%d')
 
