@@ -46,7 +46,10 @@ class NaPoleonDropboxConnector(object):
         dataframe = pd.read_csv(string_data_csv, sep=sep)
         if index_date:
             if not 'date' in list(dataframe.columns):
-                dataframe = dataframe.rename(columns={"Unnamed: 0": "date"}, errors="raise")
+                try:
+                    dataframe = dataframe.rename(columns={"Unnamed: 0": "date"}, errors="raise")
+                except:
+                    dataframe = dataframe.rename(columns={"datetime": "date"}, errors="raise")
             dataframe['date'] = pd.to_datetime(dataframe['date'])
             dataframe = dataframe.sort_values(by=['date'])
             dataframe = dataframe.set_index(dataframe['date'])
