@@ -5,7 +5,6 @@ import lightgbm as lgb
 import numpy as np
 
 from sklearn.model_selection import cross_val_score, GridSearchCV, KFold, RandomizedSearchCV, train_test_split
-from napoleontoolbox.forecasting import preprocessing_features
 
 
 
@@ -13,10 +12,6 @@ class LGBMModel():
 
     def __init__(self, preprocessing = False, threshold = 0.6, number_per_year=252):
         self.model = lgb.LGBMRegressor()
-        self.preprocessing = preprocessing
-        self.threshold = threshold
-        self.columns_to_drop = np.array([])
-        self.binarization_threshold = dict()
 
     def calibrate(self, X, y):#, method = 'standard'):
         param_grid = {
@@ -34,22 +29,9 @@ class LGBMModel():
         return best_params
 
     def fit(self, X_train, y_train, X_val, y_val):#, method = 'standard'):
-        if self.preprocessing:
-            self.columns_to_drop = preprocessing_features.most_correlated_features(X_train,self.threshold)
-            X_train = X_train.drop(self.columns_to_drop,axis=1)
-            X_val = X_val.drop(self.columns_to_drop,axis=1)
-
-            self.binarization_threshold = preprocessing_features.get_binarization_threshold(X_train)
-            X_train = preprocessing_features.binarize_features(X_train,self.binarization_threshold)
-            X_val = preprocessing_features.binarize_features(X_val, self.binarization_threshold)
-
         self.model.fit(X_train, y_train, eval_set=[(X_val, y_val)], eval_metric=['l1', 'l2'], early_stopping_rounds=5,verbose=0)
 
     def predict(self, X_test):#, method = 'standard'):
-        if self.preprocessing:
-            X_test = X_test.drop(self.columns_to_drop, axis=1)
-            X_test = preprocessing_features.binarize_features(X_test, self.binarization_threshold)
-
         y_pred = self.model.predict(X_test)
         return y_pred
 
