@@ -55,8 +55,8 @@ def plot_stacked_bar(data_df, title = ''):
         me_x=list(range(len(data_df.index)))
         me_x=data_df.index
         me_y=data_df[col].values
-        print(me_x)
-        print(me_y)
+        #print(me_x)
+        #print(me_y)
         ts_data.append(go.Bar(name=col, x=me_x, y=me_y))
 
     fig = go.Figure(data=ts_data)
