@@ -574,9 +574,9 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
 
         actualPositions = binance_get_position_risk(public_key,private_key,start_time, end_time)
         history_balance = binance_get_future_balance_history(public_key,private_key,start_time, end_time)
+        walletHist = binance_get(public_key, private_key, 'wallet_history', start_time, end_time= end_time, symbol ='ETHUSDT')
 
         trades = binance_get(public_key, private_key, 'trade_history', start_time, end_time=end_time, symbol ='ETHUSDT').drop_duplicates()
-        walletHist = binance_get(public_key, private_key, 'wallet_history', start_time, end_time= end_time, symbol ='ETHUSDT')
 
         walletHist = walletHist[~walletHist['incomeType'].isin(['API_REBATE'])]
 
@@ -599,7 +599,10 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
 
         history_balance['convertedWalletBalance'] = history_balance.apply(convert_bnb_to_usdt, axis=1)
 
-        converted_history_balance = history_balance[['ts','convertedWalletBalance']].groupby('ts').sum()
+        converted_history_balance = history_balance[['date','convertedWalletBalance']].groupby('date').sum()
+
+        #### @todo check this is ok for it
+        converted_history_balance['convertedWalletBalance'] = converted_history_balance['convertedWalletBalance'].shift(-1)
 
         if save_to_dropbox :
             full_path = local_root_directory + trade_pkl_file_name
@@ -667,7 +670,22 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
     ohlc_bnb_min_binance.columns = [x + '_bnb_bnc' for x in ohlc_bnb_min_binance.columns]
     ohlc_bnb_min_binance.index = ohlc_bnb_min_binance.index.tz_localize(None)
 
+    def filter_me_month(data_df, filtering_month):
+        if 'Date' not in data_df.columns:
+            data_df['Date'] = pd.to_datetime(data_df.index)
+        data_df['month'] = data_df['Date'].dt.month
+        data_df['insideMonth'] = data_df['month'] == filtering_month
+        data_df = data_df[data_df['insideMonth']].copy()
+        data_df = data_df.drop(columns=['month', 'insideMonth'])
+        return data_df
 
+    prev_month_converted_history_balance = filter_me_month(converted_history_balance.copy(),me_month-1)
+
+    starting_valo = None
+    try:
+        starting_valo =prev_month_converted_history_balance['convertedWalletBalance'].tail(1)[0]
+    except Exception as e:
+        print(e)
     ##################################
     #################
     ################# Positions
@@ -736,6 +754,25 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
 
     first_summary_df = trades_df.groupby(['Security Code', 'Oper'])['Amount'].sum()
 
+    if not by_pass_month:
+        walletHist['Date'] = pd.to_datetime(walletHist['ts'])
+        walletHist = filter_me_month(walletHist.copy(),me_month)
+
+    walletHist=walletHist.reset_index()
+    walletHist['income'] = walletHist['income'].astype(float)
+    valo_over_time = np.zeros(len(walletHist))
+    for index, row in walletHist.iterrows():
+        if index == 0:
+            if row['incomeType'] == 'TRANSFER':
+                valo_over_time[index] = row['income']
+                continue
+            else :
+                valo_over_time[index] = starting_valo
+                continue
+        valo_over_time[index] = valo_over_time[index-1]+row['income']
+
+    walletHist['valo_over_time'] = valo_over_time
+
     futures_income_history_df = walletHist[
         walletHist['incomeType'] == 'FUNDING_FEE'].copy()
     futures_income_history_df['Nature'] = 'CRY'
@@ -744,7 +781,6 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
         'asset': 'Currency',
         'incomeType': 'Oper',
         'income': 'Fees',
-        'ts': 'Date'
     })
     futures_income_history_columns = ['Nature', 'Security Code', 'Currency', 'Oper', 'Date', 'Fees']
     futures_income_history_df = futures_income_history_df[
@@ -757,9 +793,8 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
     binance_df['Date'] = pd.to_datetime(binance_df['Date'])
     binance_df = binance_df.sort_values(by=['Date'])
 
-    binance_df['Fees'] = -binance_df['Fees'].astype(float)
-
-
+    #binance_df['Fees'] = -binance_df['Fees'].astype(float)
+    converted_history_balance = converted_history_balance.dropna()
     filteredWallet = converted_history_balance.copy()
     converted_history_balance['Date'] = converted_history_balance.index
     filteredWallet['Date'] = filteredWallet.index
@@ -779,17 +814,13 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
     minDate = min(converted_history_balance.index)
     maxDate = max(converted_history_balance.index)
 
-    def filter_me_month(data_df, filtering_month):
-        data_df['month'] = data_df['Date'].dt.month
-        data_df['insideMonth'] = data_df['month'] == filtering_month
-        data_df = data_df[data_df['insideMonth']].copy()
-        data_df = data_df.drop(columns=['month', 'insideMonth'])
-        return data_df
+
 
     if not by_pass_month:
         filtered_binance_df=filter_me_month(binance_df.copy(),me_month)
         funding_df=filter_me_month(funding_df.copy(),me_month)
 
+
     filteredWallet = filteredWallet.rename(columns = {
         'convertedWalletBalance': 'wallet_balance_usdt'
     })
@@ -840,6 +871,8 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
 
     filtered_binance_df['Currency'] = 'UST'
 
+    filtered_binance_df.iloc[:,len(filtered_binance_df.columns)-1]=''
+
     funding_df['Date'] = funding_df['Date'].dt.strftime('%d/%m/%Y')
 
     funding_df['Value'] = funding_df['Date']
@@ -856,7 +889,7 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
 
     summary_df = filtered_binance_df.groupby(['Security Code', 'Oper'])['Amount'].sum()
     summary_df = summary_df.reset_index()
-    return filtered_binance_df, finalFilteredWallet, final_converted_history_balance, actualPositions, funding_df, summary_df
+    return filtered_binance_df, finalFilteredWallet, final_converted_history_balance, actualPositions, funding_df, summary_df, walletHist
 
 
 
@@ -1078,7 +1111,7 @@ def fetch_all_necessary_data_granular(public_key = None, private_key= None, star
 
 
 
-def fetch_all_necessary_data(public_key = None, private_key= None, start_time= None, end_time= None, save_to_dropbox = False, dropbox_token = None, local_root_directory = './', trade_only_granularity = False):
+def fetch_all_necessary_data(public_key = None, private_key= None, start_time= None, end_time= None, save_to_dropbox = False, dropbox_token = None, local_root_directory = './', trade_only_granularity = False, me_month=None):
     dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=dropbox_token, dropbox_backup=True)
 
     start_time_stub = start_time.strftime('%d_%b_%Y')
@@ -1152,13 +1185,49 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
 
     converted_history_balance = history_balance[['ts','convertedWalletBalance']].groupby('ts').sum()
 
+    walletHist = binance_get(public_key, private_key, 'wallet_history', start_time, end_time= end_time, symbol ='ETHUSDT')
+
+
+
+    def filter_me_month(data_df, filtering_month):
+        data_df['month'] = data_df['Date'].dt.month
+        data_df['insideMonth'] = data_df['month'] == filtering_month
+        data_df = data_df[data_df['insideMonth']].copy()
+        data_df = data_df.drop(columns=['month', 'insideMonth'])
+        return data_df
+
+    walletHist['Date'] = pd.to_datetime(walletHist['time'], unit='ms')
+    walletHist=filter_me_month(walletHist.copy(),me_month)
+
+
+    rebateHist = walletHist[walletHist['incomeType'].isin(['API_REBATE'])].copy()
+    rebateHist['income'] = rebateHist['income'].astype(float)
+
+    def turncate_to_min(row):
+        new_date = row['Date'].floor('min')
+        return new_date
+
+    rebateHist['TruncDate'] = rebateHist.apply(turncate_to_min, axis=1)
+
+    rebateHist = pd.merge(rebateHist, ohlc_bnb_min_binance[['ts','open']], how='left', left_on = 'TruncDate', right_on = 'ts')
+
+    def convert_bnb_to_usdt(row):
+        if row['asset'] == 'BNB':
+            return float(row['income']) * float(row['open'])
+        elif row['asset'] == 'USDT':
+            return float(row['income'])
+        else :
+            return np.nan
+
+    rebateHist['convertedIncome'] = rebateHist.apply(convert_bnb_to_usdt, axis=1)
+    rebateHistSummary = rebateHist.groupby(['info', 'asset', 'symbol'])['convertedIncome'].sum()
+
+
+    walletHist = walletHist[~walletHist['incomeType'].isin(['API_REBATE'])]
 
     trades = binance_get(public_key, private_key, 'trade_history', start_time, end_time=end_time, symbol ='ETHUSDT').drop_duplicates()
     ohlc_eth_binance = binance_get(public_key, private_key, 'futures_klines', start_time, end_time= end_time, symbol ='ETHUSDT', aggreg ='1m')
     ohlc_btc_binance = binance_get(public_key, private_key, 'futures_klines', start_time, end_time= end_time, symbol ='BTCUSDT', aggreg ='1m')
-    walletHist = binance_get(public_key, private_key, 'wallet_history', start_time, end_time= end_time, symbol ='ETHUSDT')
-
-    walletHist = walletHist[~walletHist['incomeType'].isin(['API_REBATE'])]
 #    initial_balance_time =  min(pd.to_datetime(trades['time'], unit='ms'))
 
  #   print(f'found balance {initial_balances} at {initial_balance_time}')
@@ -1447,4 +1516,4 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
         print(f'uploading to dropbox {full_path}')
         dbx.upload(fullname=full_path, folder='', subfolder='', name=report_pkl_file_name, overwrite=True)
         os.remove(full_path)
-    return x
+    return x,rebateHistSummary
