@@ -12,7 +12,7 @@ import pandas as pd
 from scipy.optimize import Bounds, LinearConstraint, minimize
 from napoleontoolbox.utility import metrics
 import numpy as np
-
+from datetime import timedelta
 # Internal packages
 
 
@@ -518,6 +518,27 @@ def roll_sharpe(series, period=252, win=0, cap=True):
     return rolledSeries.values
 
 
+def rescale(me_serie = None, me_date = None, initial_price = 1.):
+    rescaled_serie = pd.Series(np.nan, index = me_serie.index)
+    me_index = None
+    me_value = 0.
+    while me_index == None or abs(me_value) <= 1e-10 or  np.isnan(me_value):
+        try:
+            me_index = me_serie.index.get_loc(me_date)
+            if me_index - 1 >= 0 :
+                me_value = me_serie.iloc[me_index-1]
+            else:
+                me_value = initial_price
+            me_date=me_date+timedelta(days=1)
+        except Exception as e:
+            print(e)
+            me_date=me_date+timedelta(days=1)
+
+    me_serie_return_values = me_serie.pct_change().iloc[me_index:].fillna(0.)
+    me_serie_return_values = me_serie_return_values.values
+    rescaled_serie.values[me_index:] = from_ret_to_price(me_serie_return_values, initial_price=initial_price)
+    return rescaled_serie
+
 def from_ret_to_price(series, initial_price = 1.):
     return initial_price * (1 + series).cumprod()
 
